pub struct MolecularFormula { /* private fields */ }Implementations
Sourceimpl MolecularFormula
impl MolecularFormula
pub fn new() -> Self
pub fn elements(&self) -> &IntMap<u8, usize>
Sourcepub fn merge(&mut self, other: &MolecularFormula)
pub fn merge(&mut self, other: &MolecularFormula)
Merges two molecular formulas.
Examples
use molecules::molecular_formula::MolecularFormula;
let water = "H2O".parse::<MolecularFormula>().unwrap();
let methane = "CH4".parse::<MolecularFormula>().unwrap();
let mut water_methane = water.clone();
water_methane.merge(&methane);
assert_eq!(water_methane, "CH4H2O".parse::<MolecularFormula>().unwrap());
assert_eq!(water, "H2O".parse::<MolecularFormula>().unwrap());
assert_eq!(methane, "CH4".parse::<MolecularFormula>().unwrap());
assert_eq!(water_methane, "CH4H2O".parse::<MolecularFormula>().unwrap());
Sourcepub fn combine(&self, other: &MolecularFormula) -> Self
pub fn combine(&self, other: &MolecularFormula) -> Self
Combines two molecular formulas.
Examples
use molecules::molecular_formula::MolecularFormula;
let water = "H2O".parse::<MolecularFormula>().unwrap();
let methane = "CH4".parse::<MolecularFormula>().unwrap();
let water_methane = water.combine(&methane);
assert_eq!(water_methane, "CH4H2O".parse::<MolecularFormula>().unwrap());Sourcepub fn monoisotopic_mass(&self) -> f64
pub fn monoisotopic_mass(&self) -> f64
Calculates the monoisotopic mass of the molecular formula.
Examples
use molecules::molecular_formula::MolecularFormula;
let water = "H2O".parse::<MolecularFormula>().unwrap();
let methane = "CH4".parse::<MolecularFormula>().unwrap();
println!("{:?}", water);
assert_eq!(water.monoisotopic_mass().round(), 18.0);
assert_eq!(methane.monoisotopic_mass().round(), 16.0);
Sourcepub fn molecular_mass(&self) -> Option<f64>
pub fn molecular_mass(&self) -> Option<f64>
Calculates the molecular mass of the molecular formula. Since some elements do not have a standard atomic weight, this function returns an Option.
Examples
use molecules::molecular_formula::MolecularFormula;
let water = "H2O".parse::<MolecularFormula>().unwrap();
let methane = "CH4".parse::<MolecularFormula>().unwrap();
assert_eq!(water.molecular_mass().unwrap().round(), 18.0);
assert_eq!(methane.molecular_mass().unwrap().round(), 16.0);Trait Implementations
Sourceimpl Clone for MolecularFormula
impl Clone for MolecularFormula
Sourcefn clone(&self) -> MolecularFormula
fn clone(&self) -> MolecularFormula
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MolecularFormula
impl Debug for MolecularFormula
Sourceimpl Default for MolecularFormula
impl Default for MolecularFormula
Sourceimpl Display for MolecularFormula
impl Display for MolecularFormula
Sourceimpl FromStr for MolecularFormula
impl FromStr for MolecularFormula
Sourcefn from_str(s: &str) -> Result<Self, Self::Err>
fn from_str(s: &str) -> Result<Self, Self::Err>
Parses a molecular formula from a string.
Panics
This function does not panic. But it will ignore everything that is neither a number nor a letter
Examples
use molecules::molecular_formula::MolecularFormula;
let water = "H2O".parse::<MolecularFormula>().unwrap();
let methane = "CH4".parse::<MolecularFormula>().unwrap();
assert_eq!(water.monoisotopic_mass(), 18.01056468403);
assert_eq!(methane.monoisotopic_mass(), 16.03130012892);
Sourcetype Err = ParseFormulaError
type Err = ParseFormulaError
The associated error which can be returned from parsing.
Sourceimpl PartialEq for MolecularFormula
impl PartialEq for MolecularFormula
impl StructuralPartialEq for MolecularFormula